@@ -355,14 +355,19 @@ class WorkerTest(tests.TestCase):
             self, update_scope_processing_state_db_mock,
             persist_rating_data_mock, execute_measurements_rating_mock,
             do_collection_mock):
-        self.worker._conf = {"metrics": {"metric1": "s", "metric2": "d"}}
+        self.worker._collector = collector.gnocchi.GnocchiCollector(
+            period=3600,
+            conf=tests.samples.DEFAULT_METRICS_CONF,
+        )
         do_collection_mock.return_value = None
 
         timestamp_now = tzutils.localized_now()
         self.worker.do_execute_scope_processing(timestamp_now)
 
         do_collection_mock.assert_has_calls([
-            mock.call(["metric1", "metric2"], timestamp_now)
+            mock.call(['cpu@#instance', 'image.size', 'ip.floating',
+                       'network.incoming.bytes', 'network.outgoing.bytes',
+                       'radosgw.objects.size', 'volume.size'], timestamp_now)
         ])
 
         self.assertFalse(execute_measurements_rating_mock.called)
@@ -378,7 +383,10 @@ class WorkerTest(tests.TestCase):
             self, update_scope_processing_state_db_mock,
             persist_rating_data_mock, execute_measurements_rating_mock,
             do_collection_mock):
-        self.worker._conf = {"metrics": {"metric1": "s", "metric2": "d"}}
+        self.worker._collector = collector.gnocchi.GnocchiCollector(
+            period=3600,
+            conf=tests.samples.DEFAULT_METRICS_CONF,
+        )
 
         usage_data_mock = {"some_usage_data": 2}
         do_collection_mock.return_value = usage_data_mock
@@ -391,7 +399,9 @@ class WorkerTest(tests.TestCase):
         self.worker.do_execute_scope_processing(timestamp_now)
 
         do_collection_mock.assert_has_calls([
-            mock.call(["metric1", "metric2"], timestamp_now)
+            mock.call(['cpu@#instance', 'image.size', 'ip.floating',
+                       'network.incoming.bytes', 'network.outgoing.bytes',
+                       'radosgw.objects.size', 'volume.size'], timestamp_now)
         ])
 
         end_time = tzutils.add_delta(
@@ -406,7 +416,8 @@ class WorkerTest(tests.TestCase):
         ])
         self.assertTrue(update_scope_processing_state_db_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
+    @mock.patch("cloudkitty.storage_state.StateManager"
+                ".get_last_processed_timestamp")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -428,7 +439,8 @@ class WorkerTest(tests.TestCase):
         self.assertFalse(do_execute_scope_processing_mock.called)
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
+    @mock.patch("cloudkitty.storage_state.StateManager"
+                ".get_last_processed_timestamp")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -458,7 +470,8 @@ class WorkerTest(tests.TestCase):
         self.assertFalse(state_manager_is_storage_scope_active_mock.called)
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
+    @mock.patch("cloudkitty.storage_state.StateManager"
+                ".get_last_processed_timestamp")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -493,7 +506,8 @@ class WorkerTest(tests.TestCase):
 
         self.assertTrue(next_timestamp_to_process_mock.called)
 
-    @mock.patch("cloudkitty.storage_state.StateManager.get_state")
+    @mock.patch("cloudkitty.storage_state.StateManager"
+                ".get_last_processed_timestamp")
     @mock.patch("cloudkitty.storage_state.StateManager"
                 ".is_storage_scope_active")
     @mock.patch("cloudkitty.orchestrator.Worker.do_execute_scope_processing")
@@ -544,7 +558,7 @@ class WorkerTest(tests.TestCase):
                            "resource 'metric1'"
         expected_message = re.escape(expected_message)
 
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             collector.NoDataCollected, expected_message, self.worker._collect,
             metric, timestamp_now)
 
@@ -578,7 +592,8 @@ class WorkerTest(tests.TestCase):
         state_mock = mock.Mock()
 
         timestamp_now = tzutils.localized_now()
-        state_mock._state.get_state.return_value = timestamp_now
+        state_mock._state.get_last_processed_timestamp.return_value = \
+            timestamp_now
 
         expected_time = timestamp_now + datetime.timedelta(hours=1)
         check_time_state_mock.return_value = \
@@ -589,7 +604,7 @@ class WorkerTest(tests.TestCase):
 
         self.assertEqual(expected_time, return_of_method)
 
-        state_mock._state.get_state.assert_has_calls([
+        state_mock._state.get_last_processed_timestamp.assert_has_calls([
             mock.call(self._tenant_id)])
         check_time_state_mock.assert_has_calls([
             mock.call(timestamp_now, 3600, 2)])
@@ -613,10 +628,9 @@ class CloudKittyReprocessorTest(tests.TestCase):
 
         expected_lock_name = "<class 'cloudkitty.orchestrator." \
                              "ReprocessingWorker'>-id=scope_identifier-" \
-                             "start=%s-end=%s-current=%s" % (
+                             "start=%s-end=%s" % (
                                  scope_mock.start_reprocess_time,
-                                 scope_mock.end_reprocess_time,
-                                 scope_mock.current_reprocess_time)
+                                 scope_mock.end_reprocess_time)
 
         self.assertEqual(expected_lock_name, return_generate_lock_name)
 
@@ -921,8 +935,8 @@ class ReprocessingWorkerTest(tests.TestCase):
                            "does not seem to exist anymore."
         expected_message = re.escape(expected_message)
 
-        self.assertRaisesRegexp(Exception, expected_message,
-                                self.reprocessing_worker.load_scope_key)
+        self.assertRaisesRegex(Exception, expected_message,
+                               self.reprocessing_worker.load_scope_key)
 
         self.state_manager_get_all_mock.assert_has_calls([
             mock.call(self.reprocessing_worker._tenant_id)])
@@ -935,8 +949,8 @@ class ReprocessingWorkerTest(tests.TestCase):
                            "found for scope [toStringMock]."
         expected_message = re.escape(expected_message)
 
-        self.assertRaisesRegexp(Exception, expected_message,
-                                self.reprocessing_worker.load_scope_key)
+        self.assertRaisesRegex(Exception, expected_message,
+                               self.reprocessing_worker.load_scope_key)
 
         self.state_manager_get_all_mock.assert_has_calls([
             mock.call(self.reprocessing_worker._tenant_id)])
@@ -1025,15 +1039,16 @@ class ReprocessingWorkerTest(tests.TestCase):
             self, do_execute_scope_processing_mock_from_worker):
 
         now_timestamp = tzutils.localized_now()
+        self.reprocessing_worker.scope.start_reprocess_time = now_timestamp
         self.reprocessing_worker.do_execute_scope_processing(now_timestamp)
 
-        expected_end = tzutils.localized_now() + datetime.timedelta(
-            seconds=self.reprocessing_worker._period)
-
         self.storage_mock.delete.assert_has_calls([
-            mock.call(begin=now_timestamp, end=expected_end,
-                      filters={self.reprocessing_worker.scope_key:
-                               self.reprocessing_worker._tenant_id})])
+            mock.call(
+                begin=self.reprocessing_worker.scope.start_reprocess_time,
+                end=self.reprocessing_worker.scope.end_reprocess_time,
+                filters={
+                    self.reprocessing_worker.scope_key:
+                        self.reprocessing_worker._tenant_id})])
 
         do_execute_scope_processing_mock_from_worker.assert_has_calls([
             mock.call(now_timestamp)])
